<?php
/*
Plugin Name: Report Plugin
Description: Plugin para reportar contenido.
Plugin URI: https://josealejandro.es/report-plugin/
Version: 1.0
Author: José Alejandro
License: GPL
*/

// Enqueue scripts and styles for both admin and public pages
function enqueue_report_scripts() {
    wp_enqueue_style('report-style', plugins_url('css/report-style.css', __FILE__));
    wp_enqueue_script('jquery');
    wp_enqueue_script('report-script', plugins_url('js/report-script.js', __FILE__), array('jquery'), '1.0', true);
    wp_localize_script('report-script', 'report_script_params', array(
        'ajaxurl' => admin_url('admin-ajax.php'),
    ));
}

// Enqueue scripts for admin pages
function enqueue_report_scripts_admin($hook) {
    // Solo encola los scripts y estilos en la página del panel de informes
    if ($hook === 'toplevel_page_report-page') {
        enqueue_report_scripts();
    }
}
add_action('admin_enqueue_scripts', 'enqueue_report_scripts_admin');

// Enqueue scripts for public pages
function enqueue_report_scripts_public() {
    enqueue_report_scripts();
}
add_action('wp_enqueue_scripts', 'enqueue_report_scripts_public');


// Shortcode para mostrar el botón de reportar
function report_button_shortcode($atts) {
    $title = isset($atts['title']) ? esc_attr($atts['title']) : 'Reportar';
    $style = isset($atts['style']) ? esc_attr($atts['style']) : 'background-color: orange; color: white;';
    $post_id = get_the_ID();

    ob_start();
    ?>
    <button class="report-button" data-post-id="<?php echo esc_attr($post_id); ?>" style="<?php echo esc_attr($style); ?>"><?php echo esc_html($title); ?></button>
    <?php
    return ob_get_clean();
}
add_shortcode('report_button', 'report_button_shortcode');

// Función para manejar el reporte
function report_post_frontend() {
    $post_id = isset($_POST['post_id']) ? intval($_POST['post_id']) : 0;

    if ($post_id > 0) {
        // Obtener los reportes almacenados
        $reports = get_option('reported_posts', array());

        // Incrementar el contador de reportes
        $reports[$post_id] = isset($reports[$post_id]) ? $reports[$post_id] + 1 : 1;
        update_option('reported_posts', $reports);

        // Actualizar la fecha del último reporte en el post
        update_post_meta($post_id, 'last_report_date', current_time('mysql'));

        // Mostrar un mensaje de agradecimiento al usuario
        echo '¡Muchas gracias por avisar!';
    } else {
        // Mostrar un mensaje de error
        echo 'Error al procesar la solicitud.';
    }

    // ¡Importante! Esto evita que WordPress añada "0" al final de la respuesta AJAX
    wp_die();
}
add_action('wp_ajax_report_post', 'report_post_frontend');
add_action('wp_ajax_nopriv_report_post', 'report_post_frontend');  // Necesario si los usuarios no están autenticados

// Crear tabla de informes en el panel de administración
function report_page_content() {
    ?>
    <div class="wrap">
        <h2>Informes de Reportes</h2>
        <div id="report-messages"></div>
        <?php
        $reports = get_option('reported_posts', array());
        if (empty($reports)) {
            echo '<p>No hay informes disponibles.</p>';
        } else {
            ?>
            <table class="wp-list-table widefat fixed striped">
                <thead>
                    <tr>
                        <th>ID Post/Página</th>
                        <th>Nombre</th>
                        <th>Fecha del último reporte</th>
                        <th>Cantidad de Reportes</th>
                        <th>Acciones</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    foreach ($reports as $post_id => $count) {
                        $post_title = get_the_title($post_id);
                        $last_report_date = get_post_meta($post_id, 'last_report_date', true);
                        ?>
                        <tr>
                            <td><?php echo $post_id; ?></td>
                            <td>
                                <?php
                                // Añadir enlace al nombre de la página
                                $edit_url = get_edit_post_link($post_id);
                                if ($edit_url) {
                                    echo '<a href="' . esc_url($edit_url) . '" target="_blank">' . esc_html($post_title) . '</a>';
                                } else {
                                    echo esc_html($post_title);
                                }
                                ?>
                            </td>
                            <td><?php echo esc_html($last_report_date); ?></td>
                            <td><?php echo $count; ?></td>
                            <td><a href="#" class="mark-as-fixed" data-post-id="<?php echo esc_attr($post_id); ?>">Marcar como solventado</a></td>
                        </tr>
                        <?php
                    }
                    ?>
                </tbody>
            </table>
            <?php
        }
        ?>
    </div>
    <script>
        jQuery(document).ready(function($) {
            $(document).on('click', '.mark-as-fixed', function(e) {
                e.preventDefault();
                var post_id = $(this).data('post-id');
                $.ajax({
                    type: 'POST',
                    url: report_script_params.ajaxurl,
                    data: {
                        action: 'mark_as_fixed',
                        post_id: post_id
                    },
                    success: function(response) {
                        $('#report-messages').html('<div class="notice notice-success is-dismissible"><p>' + response + '</p></div>');
                        // Recargar la tabla después de marcar como solventado
                        window.location.reload();
                    },
                    error: function(error) {
                        console.log(error);
                        $('#report-messages').html('<div class="notice notice-error is-dismissible"><p>Error al procesar la solicitud.</p></div>');
                    }
                });
            });
        });
    </script>
    <?php
}
add_action('admin_menu', 'register_report_page');
function register_report_page(){
    add_menu_page('Reportes', 'Reportes', 'manage_options', 'report-page', 'report_page_content', 'dashicons-warning');
}

// Función para manejar la acción "Marcar como solventado" en la tabla de informes
function mark_as_fixed() {
    $post_id = isset($_POST['post_id']) ? intval($_POST['post_id']) : 0;
    if ($post_id > 0) {
        // Eliminar el informe del array de reportes
        $reports = get_option('reported_posts', array());
        unset($reports[$post_id]);
        update_option('reported_posts', $reports);

        // Mostrar un mensaje de agradecimiento
        echo 'El informe ha sido marcado como solventado y eliminado.';
    } else {
        echo 'Error al procesar la solicitud.';
    }
    wp_die();
}
add_action('wp_ajax_mark_as_fixed', 'mark_as_fixed');
